==> jc-1.4.0.tar.gz: gnu/java/security/provider/EncodedKeyFactory.h <==
// public class gnu.java.security.provider.EncodedKeyFactory

// class file dependencies
// @dep_class 36ddc5016a1f8464 gnu_java_security_provider_EncodedKeyFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5208a7db73e048db java_security_KeyFactorySpi

// header file dependencies
// @dep_header java_security_KeyFactorySpi

#include "java/security/KeyFactorySpi.h"

#ifndef _JC_gnu_java_security_provider_EncodedKeyFactory_H_
#define _JC_gnu_java_security_provider_EncodedKeyFactory_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_spec_KeySpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs	_jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs	_jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$refs	_jc_gnu_java_security_provider_EncodedKeyFactory$refs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs	_jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$object	_jc_gnu_java_security_provider_EncodedKeyFactory$object;

typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct	_jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct;
typedef const struct _jc_gnu_java_security_provider_EncodedKeyFactory$vmethods	_jc_gnu_java_security_provider_EncodedKeyFactory$vmethods;
typedef const struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtable	_jc_gnu_java_security_provider_EncodedKeyFactory$vtable;
typedef const struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtype	_jc_gnu_java_security_provider_EncodedKeyFactory$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID__5fDH;
	struct _jc_gnu_java_security_OID$object	*ID__5fDSA;
	struct _jc_gnu_java_security_OID$object	*ID__5fRSA;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAParameterSpec;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24PKCS8EncodedKeySpec;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24X509EncodedKeySpec;
};
extern _jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct _jc_gnu_java_security_provider_EncodedKeyFactory$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_EncodedKeyFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineGeneratePrivate$5f899f5d07075f18(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineGeneratePublic$7ad176effa9fa186(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineGetKeySpec$8e11b093f262567f(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineTranslateKey$486445c69e67c534(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineGeneratePrivate$5f899f5d07075f18;
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineGeneratePublic$7ad176effa9fa186;
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineGetKeySpec$8e11b093f262567f;
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineTranslateKey$486445c69e67c534;

// Static methods
extern void _jc_gnu_java_security_provider_EncodedKeyFactory$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_provider_EncodedKeyFactory$vmethods {
	struct _jc_object	*(*engineGeneratePrivate$5f899f5d07075f18)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *);
	struct _jc_object	*(*engineGeneratePublic$7ad176effa9fa186)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *);
	struct _jc_object	*(*engineGetKeySpec$8e11b093f262567f)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
	struct _jc_object	*(*engineTranslateKey$486445c69e67c534)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyFactorySpi$vmethods	java_security_KeyFactorySpi;
	_jc_gnu_java_security_provider_EncodedKeyFactory$vmethods	gnu_java_security_provider_EncodedKeyFactory;
};

// Vtype
struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_EncodedKeyFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$refs {
    _jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs	gnu_java_security_provider_EncodedKeyFactory;
    _jc_java_security_KeyFactorySpi$sub_refs	java_security_KeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyFactorySpi$sub_nonrefs	java_security_KeyFactorySpi;
    _jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs	gnu_java_security_provider_EncodedKeyFactory;
};

// Object instance structure
struct _jc_gnu_java_security_provider_EncodedKeyFactory$object {
	_jc_gnu_java_security_provider_EncodedKeyFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_EncodedKeyFactory$vtype	*vtype;
	_jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_EncodedKeyFactory$vtype _jc_gnu_java_security_provider_EncodedKeyFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_EncodedKeyFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_EncodedKeyFactory$class_object;

#endif	/* _JC_gnu_java_security_provider_EncodedKeyFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/EncodedKeyFactory.h <==
// public class gnu.java.security.provider.EncodedKeyFactory

// class file dependencies
// @dep_class 1aa3073895493c29 gnu_java_security_provider_EncodedKeyFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5208a7db73e048db java_security_KeyFactorySpi

// header file dependencies
// @dep_header java_security_KeyFactorySpi

#include "java/security/KeyFactorySpi.h"

#ifndef _JC_gnu_java_security_provider_EncodedKeyFactory_H_
#define _JC_gnu_java_security_provider_EncodedKeyFactory_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_spec_KeySpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs	_jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs	_jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$refs	_jc_gnu_java_security_provider_EncodedKeyFactory$refs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs	_jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs;
typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$object	_jc_gnu_java_security_provider_EncodedKeyFactory$object;

typedef struct _jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct	_jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct;
typedef const struct _jc_gnu_java_security_provider_EncodedKeyFactory$vmethods	_jc_gnu_java_security_provider_EncodedKeyFactory$vmethods;
typedef const struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtable	_jc_gnu_java_security_provider_EncodedKeyFactory$vtable;
typedef const struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtype	_jc_gnu_java_security_provider_EncodedKeyFactory$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID__5fDH;
	struct _jc_gnu_java_security_OID$object	*ID__5fDSA;
	struct _jc_gnu_java_security_OID$object	*ID__5fRSA;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAParameterSpec;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24PKCS8EncodedKeySpec;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24X509EncodedKeySpec;
};
extern _jc_gnu_java_security_provider_EncodedKeyFactory$fields_struct _jc_gnu_java_security_provider_EncodedKeyFactory$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_EncodedKeyFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineGeneratePrivate$5f899f5d07075f18(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineGeneratePublic$7ad176effa9fa186(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineGetKeySpec$8e11b093f262567f(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$engineTranslateKey$486445c69e67c534(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineGeneratePrivate$5f899f5d07075f18;
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineGeneratePublic$7ad176effa9fa186;
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineGetKeySpec$8e11b093f262567f;
extern _jc_method _jc_gnu_java_security_provider_EncodedKeyFactory$method_info$engineTranslateKey$486445c69e67c534;

// Static methods
extern void _jc_gnu_java_security_provider_EncodedKeyFactory$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_EncodedKeyFactory$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_EncodedKeyFactory$vmethods {
	struct _jc_object	*(*engineGeneratePrivate$5f899f5d07075f18)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGeneratePublic$7ad176effa9fa186)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetKeySpec$8e11b093f262567f)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineTranslateKey$486445c69e67c534)(_jc_env *, struct _jc_gnu_java_security_provider_EncodedKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyFactorySpi$vmethods	java_security_KeyFactorySpi;
	_jc_gnu_java_security_provider_EncodedKeyFactory$vmethods	gnu_java_security_provider_EncodedKeyFactory;
};

// Vtype
struct _jc_gnu_java_security_provider_EncodedKeyFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_EncodedKeyFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$refs {
    _jc_gnu_java_security_provider_EncodedKeyFactory$sub_refs	gnu_java_security_provider_EncodedKeyFactory;
    _jc_java_security_KeyFactorySpi$sub_refs	java_security_KeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyFactorySpi$sub_nonrefs	java_security_KeyFactorySpi;
    _jc_gnu_java_security_provider_EncodedKeyFactory$sub_nonrefs	gnu_java_security_provider_EncodedKeyFactory;
};

// Object instance structure
struct _jc_gnu_java_security_provider_EncodedKeyFactory$object {
	_jc_gnu_java_security_provider_EncodedKeyFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_EncodedKeyFactory$vtype	*vtype;
	_jc_gnu_java_security_provider_EncodedKeyFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_EncodedKeyFactory$vtype _jc_gnu_java_security_provider_EncodedKeyFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_EncodedKeyFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_EncodedKeyFactory$class_object;

#endif	/* _JC_gnu_java_security_provider_EncodedKeyFactory_H_ */
